@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -46,7 +46,7 @@ if (sizeof($parms) == 0) {
 	exit;
 }
 
-$debug   = FALSE;
+$debug   = false;
 $host_id = '';
 $filter  = '';
 
@@ -71,7 +71,7 @@ if (sizeof($parms)) {
 				break;
 			case '-d' :
 			case '--debug' :
-				$debug = TRUE;
+				$debug = true;
 				break;
 			case '--version' :
 			case '-v' :
